{% load i18n %}

<div class="ep-help-content">
    <div>
        <h4>{% trans "Update Project Collection Workflow" %}</h4>

        <p>
            This workflow enables one to change which Physical Thing resource instances are 
            involved in a given Project. 
        </p>

        <h5><u>Required Information</u></h5>
        <ul>
            <li>Project</li>
            <li>Physical Things (studied by the Project)</li>
        </ul>

        <h5><u>Workflow Outcomes</u></h5>
        <p>
            Completion of this workflow will update a given Project resource instance and 
            the Physical Thing resources instances contained in the project's related 
            Collection resource instance. 
        </p>
        
    </div>
</div>
