{% load i18n %}

<div class="ep-help-content">
    <div>
        <h4>{% trans "Project Report Workflow" %}</h4>

        <p>This workflow outputs a report of Project-related data. Select a Project and 
            template to use in generating the report.
        </p>

        <h5><u>Required Information</u></h5>
        <ul>
            <li>Project</li>
            <li>Template (must be installed prior to using the workflow)</li>
        </ul>

        <h5><u>Workflow Outcomes</u></h5>
        <p>
            A document or presentation with content populated from data in a Project.
        </p>
        
    </div>
</div>
