{% load i18n %}

<div class="ep-help-content">
    <div>
        <h4>{% trans "Review Dataset Workflow" %}</h4>

        <p>
            This workflow does not create or update data, rather it provides a convenient 
            way to find and review 2 dimensional (X-Y) datasets associated with a 
            selected Physical Thing resource instance. 
        </p>

        <h5><u>Required Information</u></h5>
        <ul>
            <li>Physical Thing (subject of the dataset)</li>
            <li>Dataset to select for review</li>
        </ul>

        <h5><u>Workflow Outcomes</u></h5>
        <p>
            This workflow provides an opportunity to review a 2 dimensional (X-Y) dataset 
            provided that dataset has an appropriate file render configured and selected.
        </p>
        
    </div>
</div>
