{% load i18n %}

<div class="ep-help-content">
    <div>
        <h4>{% trans "Add Chemical Analysis Images Workflow" %}</h4>

        <p>
           This workflow enables you to upload images for use in Image Services to 
            associate with an "Observation" resource instance. Alternatively, you can 
            annotate an existing Image Service to provide information that helps 
            describe an Observation resource instance. In doing so, you can provide 
            explanatory graphical information derived from previously uploaded datafiles. 
        </p>

        <h5><u>Required Information</u></h5>
        <ul>
            <li>Physical Thing (subject of the dataset)</li>
            <li>Observation (resource instance)</li>
            <li>Image Service (either already existing or created by uploading an image file)</li>
        </ul>

        <h5><u>Workflow Outcomes</u></h5>
        <p>
            This workflow will associate annotations on an Image Service with information about 
            an Observation resource instance.
        </p>
        
    </div>
</div>
