{% load i18n %}

<div class="ep-help-content">
    <div>
        <h4>{% trans "Analysis Areas Workflow" %}</h4>

        <p>
            This workflow creates one or more Analysis Areas (Physical Thing resource instances)
            based on annotation of an image service. 
        </p>

        <h5><u>Required Information</u></h5>
        <ul>
            <li>Project</li>
            <li>Physical Things (studied by the Project)</li>
            <li>Image services</li>
        </ul>

        <h5><u>Workflow Outcomes</u></h5>
        <p>
            Completion of this workflow will create a new Analysis Areas (instances of the Physical 
            Thing resource model).
        </p>
        
    </div>
</div>
