{% load i18n %}
<div style="height: 100%; padding: 10px 24px;">
    <div style="padding: 5px">
        <div class="widget-input-label">{% trans "Project" %}</div>
        <div data-bind="component: {
            name: 'resource-instance-select-widget',
            params: {
                graphids: [
                    projectGraphId,
                ],
                renderContext: 'workflow', 
                value: projectValue,
                disabled: locked,
            }
        }"></div>
    </div>
    <!--ko if: termFilter() -->
    <div style="padding: 5px; margin-top: 15px;">
        <div class="widget-input-label">
            <!-- ko if: datasetRoute === undefined -->
            <div>
                {% trans "Select an Object" %}
            </div>
            <!-- /ko -->
            <!-- ko if: datasetRoute === 'non-destructive' -->
            <div>
                {% trans "Select an Object from your Project" %}
            </div>
            <div style="font-style: italic; margin-bottom: 10px;">
                {% trans "Object must have at least one analysis area or sample location" %}
            </div>
            <!-- /ko -->
            <!-- ko if:  datasetRoute === 'destructive' -->
            <div>
                {% trans "Select a Sample of interest" %}
            </div>
            <!-- /ko -->
        </div>
        <div data-bind="component: {
            name: 'resource-instance-select-widget',
            params: {
                graphids: [
                    physicalThingGraphId,
                ],
                termFilter: termFilter(),
                renderContext: 'workflow', 
                value: physicalThingValue,
                disabled: locked,
            }
        }"></div>
    </div>
    <!--/ko-->
    <!-- ko if: hasSetWithPhysicalThing() === false -->
    <div class="object-selector-label tabbed-workflow-step-information-box widget-input-label">
        {% trans "This project has no associated Objects. Your project must have an associated Object Collection with an Object before proceeding." %}
    </div>
    <!-- /ko -->
    <!-- ko if: validateThing && isPhysicalThingValid() === false -->
    <div class="object-selector-label tabbed-workflow-step-information-box widget-input-label">
        <span data-bind="if: datasetRoute == 'non-destructive'">
            {% trans "The selected object must have at least one related sample location or analysis area." %}
        </span>
        <span data-bind="if: datasetRoute == 'destructive'">
            {% trans "The selected object must be a sample." %}
        </span>
    </div>
    <!-- /ko -->
</div>
