{% extends "base-manager.htm" %}
{% load i18n %}
{% load static %}

{% block project_css %}
    <link href="https://releases.transloadit.com/uppy/v2.12.1/uppy.min.css" rel="stylesheet">  
{% endblock project_css %}