-- map search component
update search_component set sortorder=4
    where searchcomponentid='09d97fc6-8c83-4319-9cef-3aaa08c3fbec';

-- details search component
update search_component set sortorder=0
    where searchcomponentid='f5986dae-8b01-11ea-b65a-77903936669c';
