{% extends "views/components/cards/file-renderers/afs-reader.htm" %}
{% load i18n %}

{% block renderer_configuration %}
<div style="padding: 10px;">
<!-- ko component: {
    name: 'importer-configuration',
    params: {
        selectedConfiguration: selectedConfig,
        alert: alert
    }
} --> 
<!-- /ko -->
</div>
{% endblock renderer_configuration %}
