{% load static %}
{% load i18n %}

<div style="padding-left: 28px;">
    <p style="margin-top: -9px; font-size: 14; color: #666;">
        {% trans "Select the option that describes your dataset:" %}
    </p>

    <div style="display: flex;">
        <input 
            type="radio" 
            id="non-destructive" 
            value="non-destructive"
            name="dataset-type"
            data-bind="
                checked: $data.value,
                disable: $data.locked(),
                cursor: $data.locked() ? 'default' : 'pointer';
            "
            style="
                margin-top: 10px;
                margin-right: 5px;
            "
        >
        <label for="non-destructive" data-bind="cursor: $data.locked() ? 'default' : 'pointer';">
            <h5 class="afs-workflow-option">{% trans "Data from a discrete area/region of interest" %}</h5>
            <p class="afs-workflow-option-instruction">
                {% trans "Choose this dataset type for any data resulting from a non-invasive technique and/or a minimally-invasive/minimally-destructive technique performed on a larger object but which does not consume the entire object/sample. This includes datasets from non-invasive techniques performed on removed samples." %}
            </p>
        </label>
    </div>
      
    <div style="display: flex;">
        <input 
            type="radio" 
            id="destructive" 
            value="destructive"
            name="dataset-type"
            data-bind="
                checked: $data.value,
                disable: $data.locked(),
                cursor: $data.locked() ? 'default' : 'pointer';
            "
            style="
                margin-top: 10px;
                margin-right: 5px;
            "
        >
        <label for="destructive" data-bind="cursor: $data.locked() ? 'default' : 'pointer';">
            <h5 class="afs-workflow-option">{% trans "Data from the consumption of the sample or object" %}</h5>
            <p class="afs-workflow-option-instruction">
                {% trans "Choose this dataset type for any data resulting from the full destruction of a sample or object." %}
            </p>
        </label>
    </div>
</div>