{% load i18n %}
<!-- ko if: loading() === false -->
<div class="final-step">
    <div class="afs-final-step-section">
        <h5 class="summary-value">{% trans 'Project' %}</h5>
        <div class="afs-final-step-block">
            <div style="display: flex; flex-direction: column;">
                <a data-bind="attr: { href: urls.resource + '/' + projectResourceId}" target="_blank">
                    <div class="summary-value" 
                        data-bind = "text: projectName">
                    </div>
                </a>
            </div>
        </div>
    </div>

    <div class="afs-final-step-section">
        <h5 class="summary-value">{% trans 'Related Collection' %}</h5>
        <div class="afs-final-step-block">
            <div style="display: flex; flex-direction: column;">
                <a data-bind="attr: { href: urls.resource + '/' + resourceid}" target="_blank">
                    <div class="summary-value" 
                        data-bind = "text: collectionName">
                    </div>
                </a>
            </div>
        </div>
    </div>

    <div class="afs-final-step-section">
        <h5 class="summary-value">{% trans 'Physical Things' %}</h5>
        <div class="afs-final-step-block">
            <div style="display: flex; flex-direction: column;">
                <!-- ko foreach: collectionOfParentPhysThings -->
                <a class="summary-value" data-bind="clickBubble: false, attr: {href: $parent.urls.resource + '/' + resourceid}, text: name"></a>
                <!-- /ko -->
            </div>
        </div>
        <h5 class="summary-value">{% trans 'Child Physical Things' %}</h5>
        <!-- ko ifnot: collectionOfChildPhysThings().length -->
        <div class="afs-nodata-note">{% trans 'No children of this physical thing' %}</div>
        <!-- /ko -->

        <!-- ko if: collectionOfChildPhysThings().length -->
        <div class="afs-final-step-block">
            <div style="display: flex; flex-direction: column;">
                <!-- ko foreach: collectionOfChildPhysThings -->
                <a class="summary-value" data-bind="clickBubble: false, attr: {href: $parent.urls.resource + '/' + resourceid}, text: name"></a>
                <!-- /ko -->
            </div>
        </div>
        <!-- /ko -->
    </div>
</div>
<!-- /ko -->
